@@ -80,6 +80,9 @@ struct _BraseroBurnOptionsPrivate
 	GtkWidget *options_placeholder;
 	GtkWidget *button;
 
+	GtkWidget *burn;
+	GtkWidget *burn_multi;
+
 	guint not_ready_id;
 	GtkWidget *status_dialog;
 
@@ -164,30 +167,6 @@ brasero_burn_options_add_options (BraseroBurnOptions *self,
 	gtk_widget_show (priv->options);
 }
 
-static GtkWidget *
-brasero_burn_options_add_burn_button (BraseroBurnOptions *self,
-				      const gchar *text,
-				      const gchar *icon)
-{
-	BraseroBurnOptionsPrivate *priv;
-
-	priv = BRASERO_BURN_OPTIONS_PRIVATE (self);
-
-	if (priv->button) {
-		gtk_widget_destroy (priv->button);
-		priv->button = NULL;
-	}
-
-	priv->button = gtk_dialog_add_button (GTK_DIALOG (self),
-					      text,
-					      GTK_RESPONSE_OK);
-	gtk_button_set_image (GTK_BUTTON (priv->button),
-			      gtk_image_new_from_icon_name (icon,
-							    GTK_ICON_SIZE_BUTTON));
-
-	return priv->button;
-}
-
 static void
 brasero_burn_options_set_type_shown (BraseroBurnOptions *self,
 				     BraseroMediaType type)
@@ -238,14 +217,14 @@ brasero_burn_options_update_no_medium_warning (BraseroBurnOptions *self)
 	if (!priv->is_valid
 	||  !brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (priv->session))
 	||   brasero_medium_selection_get_media_num (BRASERO_MEDIUM_SELECTION (priv->selection)) != 1) {
-		brasero_notify_message_remove (BRASERO_NOTIFY (priv->message_output),
+		brasero_notify_message_remove (priv->message_output,
 					       BRASERO_BURN_OPTIONS_NO_MEDIUM_WARNING);
 		return;
 	}
 
 	/* The user may have forgotten to insert a disc so remind him of that if
 	 * there aren't any other possibility in the selection */
-	brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+	brasero_notify_message_add (priv->message_output,
 				    _("Please insert a writable CD or DVD if you don't want to write to an image file."),
 				    NULL,
 				    -1,
@@ -266,8 +245,14 @@ brasero_burn_options_not_ready_dialog_cancel_cb (GtkDialog *dialog,
 		priv->not_ready_id = 0;
 	}
 	gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
-	gtk_dialog_response (GTK_DIALOG (data),
-	                     GTK_RESPONSE_CANCEL);
+
+	if (response != GTK_RESPONSE_OK)
+		gtk_dialog_response (GTK_DIALOG (data),
+				     GTK_RESPONSE_CANCEL);
+	else {
+		priv->status_dialog = NULL;
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+	}		
 }
 
 static gboolean
@@ -299,6 +284,66 @@ brasero_burn_options_not_ready_dialog_shown_cb (GtkWidget *widget,
 	}
 }
 
+static void
+brasero_burn_options_setup_buttons (BraseroBurnOptions *self)
+{
+	BraseroBurnOptionsPrivate *priv;
+	BraseroTrackType *type;
+	gchar *label_m = "";
+	gchar *label;
+	gchar *icon;
+
+	priv = BRASERO_BURN_OPTIONS_PRIVATE (self);
+
+	/* add the new widgets */
+	type = brasero_track_type_new ();
+	brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (priv->session), type);
+	if (brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (priv->session))) {
+		label = _("Create _Image");
+		icon = "iso-image-new";
+	}
+	else if (brasero_track_type_get_has_medium (type)) {
+		/* Translators: This is a verb, an action */
+		label = _("_Copy");
+		icon = "media-optical-copy";
+	
+		label_m = _("Make _Several Copies");
+	}
+	else {
+		/* Translators: This is a verb, an action */
+		label = _("_Burn");
+		icon = "media-optical-burn";
+
+		label_m = _("Burn _Several Copies");
+	}
+
+	if (priv->burn_multi)
+		gtk_button_set_label (GTK_BUTTON (priv->burn_multi), label_m);
+	else
+		priv->burn_multi = gtk_dialog_add_button (GTK_DIALOG (self),
+							  label_m,
+							  GTK_RESPONSE_ACCEPT);
+
+	if (brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (priv->session)))
+		gtk_widget_hide (priv->burn_multi);
+	else
+		gtk_widget_show (priv->burn_multi);
+
+	if (priv->burn)
+		gtk_button_set_label (GTK_BUTTON (priv->burn), label);
+	else
+		priv->burn = gtk_dialog_add_button (GTK_DIALOG (self),
+						    label,
+						    GTK_RESPONSE_OK);
+
+	gtk_button_set_image (GTK_BUTTON (priv->burn), gtk_image_new_from_icon_name (icon, GTK_ICON_SIZE_BUTTON));
+
+	gtk_widget_set_sensitive (priv->burn, priv->is_valid);
+	gtk_widget_set_sensitive (priv->burn_multi, priv->is_valid);
+
+	brasero_track_type_free (type);
+}
+
 static void
 brasero_burn_options_update_valid (BraseroBurnOptions *self)
 {
@@ -310,17 +355,18 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 	valid = brasero_session_cfg_get_error (priv->session);
 	priv->is_valid = BRASERO_SESSION_IS_VALID (valid);
 
-	gtk_widget_set_sensitive (priv->button, priv->is_valid);
+	brasero_burn_options_setup_buttons (self);
+
 	gtk_widget_set_sensitive (priv->options, priv->is_valid);
 	gtk_widget_set_sensitive (priv->properties, priv->is_valid);
 
 	if (priv->message_input) {
 		gtk_widget_hide (priv->message_input);
-		brasero_notify_message_remove (BRASERO_NOTIFY (priv->message_input),
+		brasero_notify_message_remove (priv->message_input,
 					       BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
 
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message_output),
+	brasero_notify_message_remove (priv->message_output,
 				       BRASERO_NOTIFY_CONTEXT_SIZE);
 
 	if (valid == BRASERO_SESSION_NOT_READY) {
@@ -373,19 +419,19 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		/* Here there is an alternative: we may be able to span the data
 		 * across multiple media. So try that. */
 		if (available_space > min_disc_size
-		&& brasero_session_span_possible (BRASERO_SESSION_SPAN (priv->session)) == BRASERO_BURN_RETRY) {
+		&&  brasero_session_span_possible (BRASERO_SESSION_SPAN (priv->session)) == BRASERO_BURN_RETRY) {
 			GtkWidget *message;
 
-			message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+			message = brasero_notify_message_add (priv->message_output,
 							      _("Would you like to burn the selection of files across several media?"),
 							      _("The data size is too large for the disc even with the overburn option."),
 							      -1,
 							      BRASERO_NOTIFY_CONTEXT_SIZE);
-			brasero_notify_button_add (BRASERO_NOTIFY (priv->message_output),
-						   BRASERO_DISC_MESSAGE (message),
-						   _("_Burn Several Discs"),
-						   _("Burn the selection of files across several media"),
-						   GTK_RESPONSE_OK);
+
+			gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+									      _("_Burn Several Discs"),
+									      GTK_RESPONSE_OK),
+						    _("Burn the selection of files across several media"));
 
 			g_signal_connect (message,
 					  "response",
@@ -393,21 +439,21 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 					  self);
 		}
 		else
-			brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+			brasero_notify_message_add (priv->message_output,
 						    _("Please choose another CD or DVD or insert a new one."),
 						    _("The data size is too large for the disc even with the overburn option."),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
-		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+		brasero_notify_message_add (priv->message_output,
 					    _("Please insert a writable CD or DVD."),
 					    NULL,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
 	else if (valid == BRASERO_SESSION_NO_CD_TEXT) {
-		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+		brasero_notify_message_add (priv->message_output,
 					    _("No track information (artist, title, ...) will be written to the disc."),
 					    _("This is not supported by the current active burning backend."),
 					    -1,
@@ -420,19 +466,19 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (priv->session), type);
 
 		if (brasero_track_type_get_has_data (type))
-			brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+			brasero_notify_message_add (priv->message_output,
 						    _("Please add files."),
 						    _("There are no files to write to disc"),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 		else if (!BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (type)))
-			brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+			brasero_notify_message_add (priv->message_output,
 						    _("Please add songs."),
 						    _("There are no songs to write to disc"),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 		else
-			brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+			brasero_notify_message_add (priv->message_output,
 						     _("Please add videos."),
 						    _("There are no videos to write to disc"),
 						    -1,
@@ -446,7 +492,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_input),
+			message = brasero_notify_message_add (priv->message_input,
 							      _("Please insert a disc holding data."),
 							      _("There is no inserted disc to copy."),
 							      -1,
@@ -458,7 +504,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_input),
+			message = brasero_notify_message_add (priv->message_input,
 							      _("Please select a disc image."),
 							      _("There is no selected disc image."),
 							      -1,
@@ -470,7 +516,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_input),
+			message = brasero_notify_message_add (priv->message_input,
 							      /* Translators: this is a disc image not a picture */
 							      C_("disc", "Please select another image."),
 							      _("It doesn't appear to be a valid disc image or a valid cue file."),
@@ -483,7 +529,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 
 		if (priv->message_input) {
 			gtk_widget_show (priv->message_input);
-			message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_input),
+			message = brasero_notify_message_add (priv->message_input,
 							      _("Please insert a disc that is not copy protected."),
 							      _("All required applications and libraries are not installed."),
 							      -1,
@@ -491,7 +537,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		}
 	}
 	else if (valid == BRASERO_SESSION_NOT_SUPPORTED) {
-		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+		brasero_notify_message_add (priv->message_output,
 		                            _("Please replace the disc with a supported CD or DVD."),
 		                            NULL,
 		                            -1,
@@ -500,18 +546,18 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 	else if (valid == BRASERO_SESSION_OVERBURN_NECESSARY) {
 		GtkWidget *message;
 
-		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+		message = brasero_notify_message_add (priv->message_output,
 						      _("Would you like to burn beyond the disc's reported capacity?"),
 						      _("The data size is too large for the disc and you must remove files from the selection otherwise."
 							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
 							"\nNOTE: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message_output),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("_Overburn"),
-					   _("Burn beyond the disc's reported capacity"),
-					   GTK_RESPONSE_OK);
+
+		gtk_widget_set_tooltip_text (gtk_info_bar_add_button (GTK_INFO_BAR (message),
+								      _("_Overburn"),
+								      GTK_RESPONSE_OK),
+					     _("Burn beyond the disc's reported capacity"));
 
 		g_signal_connect (message,
 				  "response",
@@ -520,11 +566,12 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 	}
 	else if (brasero_burn_session_same_src_dest_drive (BRASERO_BURN_SESSION (priv->session))) {
 		/* The medium is valid but it's a special case */
-		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
+		brasero_notify_message_add (priv->message_output,
 					    _("The drive that holds the source disc will also be the one used to record."),
 					    _("A new writable disc will be required once the currently loaded one has been copied."),
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
+		gtk_widget_show_all (priv->message_output);
 	}
 
 	brasero_burn_options_update_no_medium_warning (self);
@@ -552,6 +599,7 @@ static void
 brasero_burn_options_build_contents (BraseroBurnOptions *object)
 {
 	BraseroBurnOptionsPrivate *priv;
+	GtkWidget *content_area;
 	GtkWidget *selection;
 	GtkWidget *alignment;
 	gchar *string;
@@ -567,19 +615,13 @@ brasero_burn_options_build_contents (BraseroBurnOptions *object)
 
 	/* Create a cancel button */
 	gtk_dialog_add_button (GTK_DIALOG (object),
-			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-
-	/* Create a default Burn button */
-	priv->button = gtk_dialog_add_button (GTK_DIALOG (object),
-					      _("_Burn"),
-					      GTK_RESPONSE_OK);
-	gtk_button_set_image (GTK_BUTTON (priv->button),
-			      gtk_image_new_from_icon_name ("media-optical-burn",
-							    GTK_ICON_SIZE_BUTTON));
+			       GTK_STOCK_CANCEL,
+			       GTK_RESPONSE_CANCEL);
 
 	/* Create an upper box for sources */
 	priv->source_placeholder = gtk_alignment_new (0.0, 0.5, 1.0, 1.0);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (object));
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    priv->source_placeholder,
 			    FALSE,
 			    TRUE,
@@ -622,7 +664,7 @@ brasero_burn_options_build_contents (BraseroBurnOptions *object)
 	g_free (string);
 	gtk_widget_show (selection);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    selection,
 			    FALSE,
 			    TRUE,
@@ -631,7 +673,7 @@ brasero_burn_options_build_contents (BraseroBurnOptions *object)
 	/* Create a lower box for options */
 	alignment = gtk_alignment_new (0.0, 0.5, 1.0, 1.0);
 	gtk_widget_show (alignment);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    alignment,
 			    FALSE,
 			    TRUE,
@@ -695,11 +737,9 @@ brasero_burn_options_setup_audio (BraseroBurnOptions *self)
 
 	priv->has_audio = TRUE;
 	gtk_window_set_title (GTK_WINDOW (self), _("Disc Burning Setup"));
-	brasero_burn_options_add_burn_button (self,
-					      _("_Burn"),
-					      "media-optical-burn");
 	brasero_burn_options_set_type_shown (BRASERO_BURN_OPTIONS (self),
-					     BRASERO_MEDIA_TYPE_WRITABLE);
+					     BRASERO_MEDIA_TYPE_WRITABLE|
+					     BRASERO_MEDIA_TYPE_FILE);
 }
 
 static void
@@ -715,9 +755,6 @@ brasero_burn_options_setup_video (BraseroBurnOptions *self)
 
 	priv->has_video = TRUE;
 	gtk_window_set_title (GTK_WINDOW (self), _("Disc Burning Setup"));
-	brasero_burn_options_add_burn_button (self,
-					      _("_Burn"),
-					      "media-optical-burn");
 	brasero_burn_options_set_type_shown (BRASERO_BURN_OPTIONS (self),
 					     BRASERO_MEDIA_TYPE_WRITABLE|
 					     BRASERO_MEDIA_TYPE_FILE);
@@ -838,9 +875,6 @@ brasero_burn_options_setup_data (BraseroBurnOptions *self)
 
 	priv->has_data = TRUE;
 	gtk_window_set_title (GTK_WINDOW (self), _("Disc Burning Setup"));
-	brasero_burn_options_add_burn_button (self,
-					      _("_Burn"),
-					      "media-optical-burn");
 	brasero_burn_options_set_type_shown (BRASERO_BURN_OPTIONS (self),
 					     BRASERO_MEDIA_TYPE_WRITABLE|
 					     BRASERO_MEDIA_TYPE_FILE);
@@ -859,9 +893,6 @@ brasero_burn_options_setup_image (BraseroBurnOptions *self)
 
 	priv->has_image = TRUE;
 	gtk_window_set_title (GTK_WINDOW (self), _("Image Burning Setup"));
-	brasero_burn_options_add_burn_button (self,
-					      _("_Burn"),
-					      "media-optical-burn");
 	brasero_burn_options_set_type_shown (self, BRASERO_MEDIA_TYPE_WRITABLE);
 
 	/* Image properties */
@@ -890,9 +921,6 @@ brasero_burn_options_setup_disc (BraseroBurnOptions *self)
 
 	priv->has_disc = TRUE;
 	gtk_window_set_title (GTK_WINDOW (self), _("Copy CD/DVD"));
-	brasero_burn_options_add_burn_button (self,
-					      _("_Copy"),
-					      "media-optical-copy");
 
 	/* take care of source media */
 	source = brasero_src_selection_new (BRASERO_BURN_SESSION (priv->session));
@@ -950,6 +978,8 @@ brasero_burn_options_setup (BraseroBurnOptions *self)
 			brasero_burn_options_setup_audio (self);
 	}
 	brasero_track_type_free (type);
+
+	brasero_burn_options_setup_buttons (self);
 }
 
 static void
@@ -1011,9 +1041,6 @@ brasero_burn_options_set_property (GObject *object,
 		brasero_burn_options_build_contents (BRASERO_BURN_OPTIONS (object));
 		brasero_burn_options_setup (BRASERO_BURN_OPTIONS (object));
 
-		/* Only try to set a better drive if there isn't one already set */
-		if (!brasero_burn_session_get_burner (BRASERO_BURN_SESSION (priv->session)))
-			brasero_dest_selection_choose_best (BRASERO_DEST_SELECTION (priv->selection));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1166,8 +1193,8 @@ brasero_burn_options_list_missing (BraseroPluginErrorType type,
 	}
 	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
 		g_string_append_c (string, '\n');
-		/* Translators: %s is the name of a missing Gstreamer plugin */
-		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
+		/* Translators: %s is the name of a missing GStreamer plugin */
+		g_string_append_printf (string, _("%s (GStreamer plugin)"), detail);
 	}
 
 	return BRASERO_BURN_OK;
